Installing
==========

You can use Python's easy_install tool::

    c:\\> easy_install tdtpy

Or, if you have pip installed, that works as well::

    c:\\> pip install tdtpy

The source code is hosted as a Mercurial repository at
http://bitbucket.org/bburan/tdtpy.

.. note::

    If you want to build a local copy of the documentation, you'll need to
    install the Python modules `sphinx` and `numpydoc`.  Keep in mind that the
    most recent version is always `hosted at readthedocs.org`_.

.. _hosted at readthedocs.org: http://tdtpy.readthedocs.org
